//==============================================================================
//    INSPECTRON AG,  Bhnirainstrasse 13, CH-8800 Thalwil, Switzerland
//==============================================================================
//	Projekt			:	Motorsteuerung
//	File				: motorcontrol.h 
//	Autor				: Ivan Dukic
//	uController	: nRF51-DK
//	Erstellt		:	18.06.2015
//==============================================================================
//	Revision:
//
//==============================================================================

#ifndef BLE_moco_H__
#define BLE_moco_H__

#include <stdint.h>
#include <stdbool.h>
#include "ble.h"
#include "ble_srv_common.h"

#define MOCO_UUID_BASE {0x23, 0xD1, 0xBC, 0xEA, 0x5F, 0x78, 0x23, 0x15, 0xDE, 0xEF, 0x12, 0x12, 0x00, 0x00, 0x00, 0x00}	//Base UUID fr den CHIP
#define MOCO_UUID_SERVICE 		0x1523							//UUID Fr Motorcontrol Service
#define MOCO_UUID_AUF_CHAR 		0x1524							//UUID Fr Button Characteristic
#define MOCO_UUID_AB_CHAR 		0x1525							//UUID Fr LED Characteristic

// Forward declaration of the ble_moco_t type. 
typedef struct ble_moco_s ble_moco_t;				//Handler auf moco Service zuweisen

typedef void (*ble_moco_auf_write_handler_t) (ble_moco_t * p_moco, uint8_t auf_state);		//Variabel auf_state an MOCO AUF handler zuweisen
typedef void (*ble_moco_ab_write_handler_t)  (ble_moco_t * p_moco, uint8_t ab_state);			//Variabel ab_state an MOCO AB handler zuweisen

typedef struct
{
	ble_moco_ab_write_handler_t 	ab_write_handler;			//Event handler wird aufgerufen, wenn AB Characteristic berschrieben wird
  ble_moco_auf_write_handler_t 	auf_write_handler;    //Event handler wird aufgerufen, wenn AUF Characteristic berschrieben wird
} ble_moco_init_t;					//Service moco

/**@brief Motorcontrol Service structure. This contains various status information for the service. */
typedef struct ble_moco_s				//Service moco
{
    uint16_t                    	service_handle;			//Service handle wird erzeugt
    ble_gatts_char_handles_t    	auf_char_handles;		//BLE handle fr AUF erzeugt
		ble_gatts_char_handles_t			ab_char_handles;		//BLE handle fr AB erzeugt
    uint8_t                     	uuid_type;					//Variabel uudi_type erzeugt
    uint16_t                    	conn_handle;				//Variabel conn_handle erzeugt
    ble_moco_auf_write_handler_t 	auf_write_handler;	//BLE Handler an auf_write_handler zuweisen
		ble_moco_ab_write_handler_t 	ab_write_handler;		//BLE Handler an ab_write_handler zuweisen
	
} ble_moco_t;						//Service moco

/**@brief Function for initializing the Motorcontrol Service.*/
uint32_t ble_moco_init(ble_moco_t * p_moco, const ble_moco_init_t * p_moco_init);

/**@brief Function for handling the Application's BLE Stack events.*/
void ble_moco_on_ble_evt(ble_moco_t * p_moco, ble_evt_t * p_ble_evt);

#endif // BLE_moco_H__

/** @} */
